@@ -28,7 +28,7 @@ exports.localization.appName ={
   "no_NO_NY": "GeoGebra klassisk",
   "pl": "Math Calcs",
   "pt": "GeoGebra Classic",
-  "ro": "GeoGebra Classic",
+  "ro": "GeoGebra Clasic",
   "ru": "GeoGebra Classic",
   "sk": "GeoGebra Classic",
   "sl": "Klasična GeoGebra",
