@@ -370,8 +370,12 @@ function updateShortcuts() {
     checkdir(0);
 }
 
-// On Raspberry Pi the GPU emulation is too slow, so we disallow using GPU completely:
-if (!(process.arch === 'arm')) {
+// On Raspberry Pi 3 the GPU emulation is too slow, so we disallow using GPU completely:
+// if (!(process.arch === 'arm')) {
+// This code has been moved into the startup script on Raspberry Pi to allow
+// detection of Raspberry Pi version (because version 4 already supports 3D well enough).
+if (forceGpu) {
+    printDebug("Ignoring GPU blacklist to enable 3D");
     app.commandLine.appendSwitch("ignore-gpu-blacklist");
 }
 
@@ -581,6 +585,7 @@ function parseCommandLineOptions() {
     forceWasm = false;
     logWatch = false;
     logExitFound = false;
+    forceGpu = true;
     var options = process.argv.length;
     var lastDetectedOption = 0;
 
@@ -588,20 +593,28 @@ function parseCommandLineOptions() {
         if (index > 0) {
             if (val.match(/^--help/)) {
                 printInfo("GeoGebra Classic 6");
-                printInfo("Copyright © The GeoGebra Group, 2018\n")
+                printInfo("Copyright © The GeoGebra Group, 2019\n")
                 printInfo("See https://www.geogebra.org/license for license conditions.");
                 printInfo("See https://www.geogebra.org/team for the list of authors.\n");
                 printInfo("Usage: " + process.argv[0] + " [options] [FILE]\n");
                 printInfo("Options:");
-                printInfo("  --help              Print this help message");
-                printInfo("  --v                 Print version");
-                printInfo("  --silent=false      Enable logging");
-                printInfo("  --giac=wasm         Disable native CAS and use WebAssembly instead");
-                printInfo("  --logexit=<text>    Exit when the log contains a given text (as regexp)");
+                printInfo("  --help               Print this help message");
+                printInfo("  --v                  Print version");
+                printInfo("  --silent=false       Enable logging");
+                printInfo("  --giac=wasm          Disable native CAS and use WebAssembly instead");
+                printInfo("  --forcegpu=<boolean> Disable/enable ignoring GPU blacklist to switch off 3D");
+                printInfo("  --logexit=<text>     Exit when the log contains a given text (as regexp)");
                 process.exit(0);
             } else if (val.match(/^--giac=wasm/)) {
                 forceWasm = true;
                 lastDetectedOption = index;
+            } else if (val.match(/^--forcegpu=/)) {
+                forceGpuInput = val.match(/^--forcegpu=(.*)/)[1];
+                if (forceGpuInput == "false" || forceGpuInput == "off" || forceGpuInput == "0")
+                    forceGpu = false;
+                else
+                    forceGpu = true;
+                lastDetectedOption = index;
             } else if (val.match(/^--logexit=/)) {
                 logWatch = true;
                 logExit = val.match(/^--logexit=(.*)/)[1];
